<?php

namespace Restaurant\DeliveryLocation\Policies;

use Litepie\User\Contracts\UserPolicy;
use Restaurant\DeliveryLocation\Models\Deliverylocation;

class DeliverylocationPolicy
{

    /**
     * Determine if the given user can view the deliverylocation.
     *
     * @param UserPolicy $user
     * @param Deliverylocation $deliverylocation
     *
     * @return bool
     */
    public function view(UserPolicy $user, Deliverylocation $deliverylocation)
    {
        if ($user->canDo('delivery_location.deliverylocation.view') && $user->isAdmin()) {
            return true;
        }

        return $deliverylocation->user_id == user_id() && $deliverylocation->user_type == user_type();
    }

    /**
     * Determine if the given user can create a deliverylocation.
     *
     * @param UserPolicy $user
     * @param Deliverylocation $deliverylocation
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('delivery_location.deliverylocation.create');
    }

    /**
     * Determine if the given user can update the given deliverylocation.
     *
     * @param UserPolicy $user
     * @param Deliverylocation $deliverylocation
     *
     * @return bool
     */
    public function update(UserPolicy $user, Deliverylocation $deliverylocation)
    {
        if ($user->canDo('delivery_location.deliverylocation.edit') && $user->isAdmin()) {
            return true;
        }

        return $deliverylocation->user_id == user_id() && $deliverylocation->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given deliverylocation.
     *
     * @param UserPolicy $user
     * @param Deliverylocation $deliverylocation
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Deliverylocation $deliverylocation)
    {
        return $deliverylocation->user_id == user_id() && $deliverylocation->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given deliverylocation.
     *
     * @param UserPolicy $user
     * @param Deliverylocation $deliverylocation
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Deliverylocation $deliverylocation)
    {
        if ($user->canDo('delivery_location.deliverylocation.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given deliverylocation.
     *
     * @param UserPolicy $user
     * @param Deliverylocation $deliverylocation
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Deliverylocation $deliverylocation)
    {
        if ($user->canDo('delivery_location.deliverylocation.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
