<?php

namespace Restaurant\DeliveryLocation\Policies;

use Litepie\User\Contracts\UserPolicy;
use Restaurant\DeliveryLocation\Models\RestaurantDeliveryLocation;

class RestaurantDeliveryLocationPolicy
{

    /**
     * Determine if the given user can view the restaurant_delivery_location.
     *
     * @param UserPolicy $user
     * @param RestaurantDeliveryLocation $restaurant_delivery_location
     *
     * @return bool
     */
    public function view(UserPolicy $user, RestaurantDeliveryLocation $restaurant_delivery_location)
    {
        if ($user->canDo('delivery_location.restaurant_delivery_location.view') && $user->isAdmin()) {
            return true;
        }

        return $restaurant_delivery_location->user_id == user_id() && $restaurant_delivery_location->user_type == user_type();
    }

    /**
     * Determine if the given user can create a restaurant_delivery_location.
     *
     * @param UserPolicy $user
     * @param RestaurantDeliveryLocation $restaurant_delivery_location
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('delivery_location.restaurant_delivery_location.create');
    }

    /**
     * Determine if the given user can update the given restaurant_delivery_location.
     *
     * @param UserPolicy $user
     * @param RestaurantDeliveryLocation $restaurant_delivery_location
     *
     * @return bool
     */
    public function update(UserPolicy $user, RestaurantDeliveryLocation $restaurant_delivery_location)
    {
        if ($user->canDo('delivery_location.restaurant_delivery_location.edit') && $user->isAdmin()) {
            return true;
        }

        return $restaurant_delivery_location->user_id == user_id() && $restaurant_delivery_location->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given restaurant_delivery_location.
     *
     * @param UserPolicy $user
     * @param RestaurantDeliveryLocation $restaurant_delivery_location
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, RestaurantDeliveryLocation $restaurant_delivery_location)
    {
        return $restaurant_delivery_location->user_id == user_id() && $restaurant_delivery_location->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given restaurant_delivery_location.
     *
     * @param UserPolicy $user
     * @param RestaurantDeliveryLocation $restaurant_delivery_location
     *
     * @return bool
     */
    public function verify(UserPolicy $user, RestaurantDeliveryLocation $restaurant_delivery_location)
    {
        if ($user->canDo('delivery_location.restaurant_delivery_location.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given restaurant_delivery_location.
     *
     * @param UserPolicy $user
     * @param RestaurantDeliveryLocation $restaurant_delivery_location
     *
     * @return bool
     */
    public function approve(UserPolicy $user, RestaurantDeliveryLocation $restaurant_delivery_location)
    {
        if ($user->canDo('delivery_location.restaurant_delivery_location.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
