<?php

namespace Restaurant\DeliveryLocation\Providers;

use Illuminate\Support\ServiceProvider;

class DeliveryLocationServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'delivery_location');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'delivery_location');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerDeliveryLocation();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerDeliveryLocation()
    {
        $this->app->bind('delivery_location', function($app) {
            return new DeliveryLocation($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('DeliveryLocation', 'Lavalite\DeliveryLocation\Facades\DeliveryLocation');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('restaurant.delivery_location', function ($app) {
            return $this->app->make('Restaurant\DeliveryLocation\DeliveryLocation');
        });

        // Bind Deliverylocation to repository
        $this->app->bind(
            'Restaurant\DeliveryLocation\Interfaces\DeliverylocationRepositoryInterface',
            \Restaurant\DeliveryLocation\Repositories\Eloquent\DeliverylocationRepository::class
        );
        // Bind RestaurantDeliveryLocation to repository
        $this->app->bind(
            'Restaurant\DeliveryLocation\Interfaces\RestaurantDeliveryLocationRepositoryInterface',
            \Restaurant\DeliveryLocation\Repositories\Eloquent\RestaurantDeliveryLocationRepository::class
        );

        $this->app->register(\Restaurant\DeliveryLocation\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Restaurant\DeliveryLocation\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and delivery_location's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'restaurant.delivery_location'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeDeliveryLocation::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['restaurant.delivery_location'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('restaurant/delivery_location.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/delivery_location')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/delivery_location')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
