<?php

namespace Restaurant\DeliveryLocation\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Restaurant\DeliveryLocation\Models\DeliveryLocation;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Restaurant\DeliveryLocation\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/delivery_location/deliverylocation/*')) {
            Route::bind('deliverylocation', function ($deliverylocation) {
                $deliverylocationrepo = $this->app->make('Restaurant\DeliveryLocation\Interfaces\DeliverylocationRepositoryInterface');
                return $deliverylocationrepo->findorNew($deliverylocation);
            });
        }

        if (Request::is('*/delivery_location/restaurant_delivery_location/*')) {
            Route::bind('restaurant_delivery_location', function ($restaurant_delivery_location) {
                $restaurant_delivery_locationrepo = $this->app->make('Restaurant\DeliveryLocation\Interfaces\RestaurantDeliveryLocationRepositoryInterface');
                return $restaurant_delivery_locationrepo->findorNew($restaurant_delivery_location);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
